SQLite-vec operations for vector storage and search.
This module handles all interactions with the SQLite database
using the sqlite-vec extension for vector similarity search.
Structs
- Search
Result - Search result from vector similarity search.
Functions
- count_
entries - Gets the total number of entries in the index.
- create_
index - Creates or overwrites the vector index with the given entries.
- get_
database_ path - Gets the path to the
SQLitedatabase. - index_
exists - Checks if the vector index exists.
- search
- Performs vector similarity search on the index.